@@ -1,5 +1,5 @@
-# Gufw 19.10.0 - http://gufw.org
-# Copyright (C) 2008-2019 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw 20.04.0 - https://costales.github.io/projects/gufw/
+# Copyright (C) 2008-2019 Marcos Alvarez Costales https://costales.github.io
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -153,11 +153,11 @@ class Gufw:
         
         # Listening report
         self.listening_model = Gtk.ListStore(str, # 0  protocol
-                                              str, # 1 port
-                                              str, # 2 address
-                                              str, # 3 app
-                                              str, # 4 color
-                                              int) # 5 number
+                                             int, # 1 port
+                                             str, # 2 address
+                                             str, # 3 app
+                                             str, # 4 color
+                                             int) # 5 number
         self.tv_report = self.report
         self.tv_report.set_model(self.listening_model)
         self.tv_report.get_selection().set_mode(Gtk.SelectionMode.SINGLE)
@@ -435,39 +435,9 @@ class Gufw:
         self.clipboard.set_text(self.frontend.get_log(), -1)
         self.set_statusbar_msg(_("Text copied to clipboard"))
     
-    def on_donate_btn_clicked(self, widget, data=None):
-        self._show_web('http://gufw.org/donate')
-    
     def on_menu_about_activate(self, widget, data=None):
         aboutwin = About(self)
     
-    def on_menu_doc_activate(self, widget, data=None):
-        self._show_web('http://help.ubuntu.com/community/Gufw')
-    
-    def on_menu_answers_activate(self, widget, data=None):
-        self._show_web('http://answers.launchpad.net/gui-ufw')
-    
-    def on_menu_bugs_activate(self, widget, data=None):
-        self._show_web('http://bugs.launchpad.net/gui-ufw')
-    
-    def on_menu_translations_activate(self, widget, data=None):
-        self._show_web('https://translations.launchpad.net/gui-ufw')
-    
-    def on_menu_donate_activate(self, widget, data=None):
-        self._show_web('http://gufw.org/donate')
-    
-    def on_menu_gplus_activate(self, widget, data=None):
-        self._show_web('http://plus.google.com/b/104342291112771981280/')
-    
-    def on_menu_gplus_community_activate(self, widget, data=None):
-        self._show_web('http://plus.google.com/communities/104067858618275933076')
-    
-    def on_menu_twitter_activate(self, widget, data=None):
-        self._show_web('http://twitter.com/gufw')
-    
-    def on_menu_identica_activate(self, widget, data=None):
-        self._show_web('http://identi.ca/gufw')
-    
     def on_menu_preferences_activate(self, widget, data=None):
         preferenceswin = Preferences(self)
     
@@ -513,7 +483,7 @@ class Gufw:
         if len(rows) == 1:
             iter_row = self.listening_model.get_iter(rows[0],)
             protocol = self.listening_model.get_value(iter_row, 0)
-            port     = self.listening_model.get_value(iter_row, 1)
+            port     = str(self.listening_model.get_value(iter_row, 1))
             address  = self.listening_model.get_value(iter_row, 2)
             app      = self.listening_model.get_value(iter_row, 3)
             if address == '*':
